import { type Transform } from '@dnd-kit-vue/utilities';
import { type Data } from '../store';
import type { UniqueIdentifier } from '../types';
import { type SyntheticListenerMap } from './utilities';
import { type ComputedRef } from 'vue';
export interface UseDraggableArguments {
    id: ComputedRef<UniqueIdentifier>;
    data?: ComputedRef<Data>;
    disabled: ComputedRef<boolean>;
    attributes?: {
        role?: string;
        roleDescription?: string;
        tabIndex?: number;
    };
}
export interface DraggableAttributes {
    role: string;
    tabIndex: number;
    'aria-disabled': boolean;
    'aria-pressed': boolean | undefined;
    'aria-roledescription': string;
    'aria-describedby': string;
}
export type DraggableSyntheticListeners = SyntheticListenerMap | undefined;
export declare function useDraggable({ id, data, disabled, attributes, }: UseDraggableArguments): {
    internalContext: import("vue").Ref<{
        activatorEvent: {
            readonly bubbles: boolean;
            cancelBubble: boolean;
            readonly cancelable: boolean;
            readonly composed: boolean;
            readonly currentTarget: {
                addEventListener: (type: string, callback: EventListenerOrEventListenerObject | null, options?: AddEventListenerOptions | boolean) => void;
                dispatchEvent: (event: Event) => boolean;
                removeEventListener: (type: string, callback: EventListenerOrEventListenerObject | null, options?: EventListenerOptions | boolean) => void;
            };
            readonly defaultPrevented: boolean;
            readonly eventPhase: number;
            readonly isTrusted: boolean;
            returnValue: boolean;
            readonly srcElement: {
                addEventListener: (type: string, callback: EventListenerOrEventListenerObject | null, options?: AddEventListenerOptions | boolean) => void;
                dispatchEvent: (event: Event) => boolean;
                removeEventListener: (type: string, callback: EventListenerOrEventListenerObject | null, options?: EventListenerOptions | boolean) => void;
            };
            readonly target: {
                addEventListener: (type: string, callback: EventListenerOrEventListenerObject | null, options?: AddEventListenerOptions | boolean) => void;
                dispatchEvent: (event: Event) => boolean;
                removeEventListener: (type: string, callback: EventListenerOrEventListenerObject | null, options?: EventListenerOptions | boolean) => void;
            };
            readonly timeStamp: DOMHighResTimeStamp;
            readonly type: string;
            composedPath: () => EventTarget[];
            initEvent: (type: string, bubbles?: boolean, cancelable?: boolean) => void;
            preventDefault: () => void;
            stopImmediatePropagation: () => void;
            stopPropagation: () => void;
            readonly NONE: 0;
            readonly CAPTURING_PHASE: 1;
            readonly AT_TARGET: 2;
            readonly BUBBLING_PHASE: 3;
        };
        activators: {
            eventName: import("../types").SyntheticEventName;
            handler: (event: any, id: UniqueIdentifier) => void;
        }[];
        active: {
            id: UniqueIdentifier;
            data: import("../store").DataRef;
            rect: any;
        };
        activeNodeRect: {
            width: number;
            height: number;
            top: number;
            left: number;
            right: number;
            bottom: number;
        };
        ariaDescribedById: {
            draggable: string;
        };
        dispatch: any;
        draggableNodes: Map<UniqueIdentifier, {
            id: UniqueIdentifier;
            key: UniqueIdentifier;
            node: any;
            activatorNode: any;
            data: import("../store").DataRef;
        }> & Omit<import("../store").DraggableNodes, keyof Map<any, any>>;
        over: {
            id: UniqueIdentifier;
            rect: {
                width: number;
                height: number;
                top: number;
                left: number;
                right: number;
                bottom: number;
            };
            disabled: boolean;
            data: import("../store").DataRef;
        };
        measureDroppableContainers: (ids: UniqueIdentifier[]) => void;
    }>;
    isDragging: import("vue").Ref<boolean>;
    attributes: import("vue").Ref<{
        role: string;
        tabIndex: number;
        'aria-disabled': boolean;
        'aria-pressed': boolean | undefined;
        'aria-roledescription': string;
        'aria-describedby': string;
    }>;
    listeners: ComputedRef<SyntheticListenerMap>;
    node: import("vue").Ref<HTMLElement>;
    setNodeRef: (element: HTMLElement | null) => void;
    setActivatorNodeRef: (element: HTMLElement | null) => void;
    transform: ComputedRef<Transform>;
};
