import { type Data } from '../store';
import type { UniqueIdentifier } from '../types';
import { type ComputedRef } from 'vue';
interface ResizeObserverConfig {
    /** Whether the ResizeObserver should be disabled entirely */
    disabled?: boolean;
    /** Resize events may affect the layout and position of other droppable containers.
     * Specify an array of `UniqueIdentifier` of droppable containers that should also be re-measured
     * when this droppable container resizes. Specifying an empty array re-measures all droppable containers.
     */
    updateMeasurementsFor?: ComputedRef<UniqueIdentifier[]>;
    /** Represents the debounce timeout between when resize events are observed and when elements are re-measured */
    timeout?: number;
}
export interface UseDroppableArguments {
    id: ComputedRef<UniqueIdentifier>;
    disabled: ComputedRef<boolean>;
    data?: ComputedRef<Data>;
    resizeObserverConfig?: ResizeObserverConfig;
}
export declare function useDroppable({ data, disabled, id, resizeObserverConfig, }: UseDroppableArguments): {
    rect: import("vue").Ref<{
        width: number;
        height: number;
        top: number;
        left: number;
        right: number;
        bottom: number;
    }>;
    isOver: ComputedRef<boolean>;
    node: import("vue").Ref<HTMLElement>;
    setNodeRef: (element: HTMLElement | null) => void;
};
export {};
