import type { SensorInstance, SensorProps, SensorOptions } from '../types';
import type { DistanceMeasurement } from '../../types';
interface DistanceConstraint {
    distance: DistanceMeasurement;
    tolerance?: DistanceMeasurement;
}
interface DelayConstraint {
    delay: number;
    tolerance: DistanceMeasurement;
}
interface EventDescriptor {
    name: keyof DocumentEventMap;
    passive?: boolean;
}
export interface PointerEventHandlers {
    move: EventDescriptor;
    end: EventDescriptor;
}
export type PointerActivationConstraint = DistanceConstraint | DelayConstraint;
export interface AbstractPointerSensorOptions extends SensorOptions {
    activationConstraint?: PointerActivationConstraint;
    onActivation?({ event }: {
        event: Event;
    }): void;
}
export type AbstractPointerSensorProps = SensorProps<AbstractPointerSensorOptions>;
export declare class AbstractPointerSensor implements SensorInstance {
    private props;
    private events;
    autoScrollEnabled: boolean;
    private document;
    private activated;
    private initialCoordinates;
    private timeoutId;
    private listeners;
    private documentListeners;
    private windowListeners;
    constructor(props: AbstractPointerSensorProps, events: PointerEventHandlers, listenerTarget?: EventTarget | Document);
    private attach;
    private detach;
    private handleStart;
    private handleMove;
    private handleEnd;
    private handleCancel;
    private handleKeydown;
    private removeTextSelection;
}
export {};
